==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/de/dc7/industry__widget_8h.js <==
var industry__widget_8h =
[
    [ "DynamicPlaceIndustriesWidgets", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bd", [
      [ "WID_DPI_MATRIX_WIDGET", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bda00064dadd52bbb90f696963f825a9042", null ],
      [ "WID_DPI_SCROLLBAR", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bda7929f843edb868b81328fee0d659d5c1", null ],
      [ "WID_DPI_INFOPANEL", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bda1c8f993e000b92b869fe354e1774e1bb", null ],
      [ "WID_DPI_DISPLAY_WIDGET", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bdac8f42e06f9f438cc09410bd097aa23c9", null ],
      [ "WID_DPI_FUND_WIDGET", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bdab0b42d251a5ca155327f97e87a56b7bd", null ]
    ] ],
    [ "IndustryCargoesWidgets", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28", [
      [ "WID_IC_CAPTION", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28aa43567c7d58e21588f9d2ee6201da279", null ],
      [ "WID_IC_NOTIFY", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28a40b42e4de8e6910e8562a01e6f82c406", null ],
      [ "WID_IC_PANEL", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28aa8e1e9df3562cb4100370152704c2c0c", null ],
      [ "WID_IC_SCROLLBAR", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28a24368de5c8fe7e94d41bea1ff779c7b6", null ],
      [ "WID_IC_CARGO_DROPDOWN", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28ac56deb1153af90b35fae5d4aa5990901", null ],
      [ "WID_IC_IND_DROPDOWN", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28a6fd75b29b6ad3794331f136c947d6346", null ]
    ] ],
    [ "IndustryDirectoryWidgets", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7", [
      [ "WID_ID_DROPDOWN_ORDER", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7a4968e2ddd579bf3ca9db0912c2c9f2af", null ],
      [ "WID_ID_DROPDOWN_CRITERIA", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7a4e5ca269f124cb658f068bb5152d2fdb", null ],
      [ "WID_ID_INDUSTRY_LIST", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7a3442b958221cde00a0b987c5593df4e1", null ],
      [ "WID_ID_SCROLLBAR", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7acddc5fef7bc94ec05dd9f6d634fdab79", null ]
    ] ],
    [ "IndustryViewWidgets", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654", [
      [ "WID_IV_CAPTION", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654a168f37880c9cf3208b6c8018bc1078c3", null ],
      [ "WID_IV_VIEWPORT", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654adcc3e207f36f58fe248298e08d6af455", null ],
      [ "WID_IV_INFO", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654a1458d48e5d3aca3035472396648d9c2c", null ],
      [ "WID_IV_GOTO", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654aa27ab07bbbd38102f2f64f8b1671e731", null ],
      [ "WID_IV_DISPLAY", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654a7112af12edeef63fd3ce4d392bd6558a", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/de/dc7/industry__widget_8h.js <==
var industry__widget_8h =
[
    [ "DynamicPlaceIndustriesWidgets", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bd", [
      [ "WID_DPI_MATRIX_WIDGET", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bda00064dadd52bbb90f696963f825a9042", null ],
      [ "WID_DPI_SCROLLBAR", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bda7929f843edb868b81328fee0d659d5c1", null ],
      [ "WID_DPI_INFOPANEL", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bda1c8f993e000b92b869fe354e1774e1bb", null ],
      [ "WID_DPI_DISPLAY_WIDGET", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bdac8f42e06f9f438cc09410bd097aa23c9", null ],
      [ "WID_DPI_FUND_WIDGET", "de/dc7/industry__widget_8h.html#ab6c63acdd81284516bf3f211f25ae6bdab0b42d251a5ca155327f97e87a56b7bd", null ]
    ] ],
    [ "IndustryCargoesWidgets", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28", [
      [ "WID_IC_CAPTION", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28aa43567c7d58e21588f9d2ee6201da279", null ],
      [ "WID_IC_NOTIFY", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28a40b42e4de8e6910e8562a01e6f82c406", null ],
      [ "WID_IC_PANEL", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28aa8e1e9df3562cb4100370152704c2c0c", null ],
      [ "WID_IC_SCROLLBAR", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28a24368de5c8fe7e94d41bea1ff779c7b6", null ],
      [ "WID_IC_CARGO_DROPDOWN", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28ac56deb1153af90b35fae5d4aa5990901", null ],
      [ "WID_IC_IND_DROPDOWN", "de/dc7/industry__widget_8h.html#a09a418fe5e4858292940dd22aacd3f28a6fd75b29b6ad3794331f136c947d6346", null ]
    ] ],
    [ "IndustryDirectoryWidgets", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7", [
      [ "WID_ID_DROPDOWN_ORDER", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7a4968e2ddd579bf3ca9db0912c2c9f2af", null ],
      [ "WID_ID_DROPDOWN_CRITERIA", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7a4e5ca269f124cb658f068bb5152d2fdb", null ],
      [ "WID_ID_FILTER_BY_ACC_CARGO", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7ac6622788ba5626cab916b75560f037df", null ],
      [ "WID_ID_FILTER_BY_PROD_CARGO", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7a4d3ceb8c14b4c2d900c44a8eb6625b1c", null ],
      [ "WID_ID_INDUSTRY_LIST", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7a3442b958221cde00a0b987c5593df4e1", null ],
      [ "WID_ID_SCROLLBAR", "de/dc7/industry__widget_8h.html#a01f7530542af07daa773a172e50e0ff7acddc5fef7bc94ec05dd9f6d634fdab79", null ]
    ] ],
    [ "IndustryViewWidgets", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654", [
      [ "WID_IV_CAPTION", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654a168f37880c9cf3208b6c8018bc1078c3", null ],
      [ "WID_IV_VIEWPORT", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654adcc3e207f36f58fe248298e08d6af455", null ],
      [ "WID_IV_INFO", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654a1458d48e5d3aca3035472396648d9c2c", null ],
      [ "WID_IV_GOTO", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654aa27ab07bbbd38102f2f64f8b1671e731", null ],
      [ "WID_IV_DISPLAY", "de/dc7/industry__widget_8h.html#ab5197284f43d1de3b6577bcbd1bcf654a7112af12edeef63fd3ce4d392bd6558a", null ]
    ] ]
];
